==> ui-react-1.0.84.tgz: package/esm/BottomAppBar/BottomAppBar.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["tonal", "color", "size", "main", "fixed", "noTransition", "className", "children"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
import React from 'react';
import { classNames, style as styleMethod, useOnesyTheme } from '@onesy/style-react';
import LineElement from '../Line';
import SurfaceElement from '../Surface';
import TransitionElement from '../Transition';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {
    zIndex: theme.z_index.app_bar,
    width: '100%',
    height: '80px',
    paddingBlock: theme.methods.space.value(1.5, 'px'),
    paddingInline: `${theme.methods.space.value(0.5, 'px')} ${theme.methods.space.value(2, 'px')}`
  },
  size_small: {
    height: '72px'
  },
  size_regular: {
    height: '80px'
  },
  size_large: {
    height: '88px'
  },
  fixed: {
    position: 'fixed',
    insetInline: '0px',
    bottom: '0px'
  },
  item: {
    opacity: '0',
    transform: 'translateY(100%)',
    transition: theme?.methods.transitions.make(['opacity', 'transform'], {
      duration: 'rg',
      timing_function: 'standard'
    }),
    '&.enter': {
      opacity: '0',
      transform: 'translateY(100%)'
    },
    '&.entering': {
      opacity: '1',
      transform: 'translateY(0%)'
    },
    '&.entered': {
      opacity: '1',
      transform: 'translateY(0%)'
    },
    '&.exit': {
      opacity: '1',
      transform: 'translateY(0%)'
    },
    '&.exiting': {
      opacity: '0',
      transform: 'translateY(0%)'
    },
    '&.exited': {
      opacity: '0',
      transform: 'translateY(0%)'
    }
  },
  mainItem: {
    opacity: '0',
    transform: 'scale(0.75)',
    transition: theme?.methods.transitions.make(['opacity', 'transform'], {
      duration: 'rg',
      timing_function: 'standard'
    }),
    '&.enter': {
      opacity: '0',
      transform: 'scale(0.75)'
    },
    '&.entering': {
      opacity: '1',
      transform: 'scale(1)'
    },
    '&.entered': {
      opacity: '1',
      transform: 'scale(1)'
    },
    '&.exit': {
      opacity: '1',
      transform: 'scale(1)'
    },
    '&.exiting': {
      opacity: '0',
      transform: 'scale(1)'
    },
    '&.exited': {
      opacity: '0',
      transform: 'scale(1)'
    }
  }
}), {
  name: 'onesy-BottomAppBar'
});
const BottomAppBar = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useOnesyTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.onesyBottomAppBar?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Surface = React.useMemo(() => theme?.elements?.Surface || SurfaceElement, [theme]);
  const Transition = React.useMemo(() => theme?.elements?.Transition || TransitionElement, [theme]);
  const {
      tonal = true,
      color = 'primary',
      size = 'regular',
      main: main_,
      fixed,
      noTransition,
      className,
      children: children_
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const makeChildren = values => {
    return React.Children.toArray(values).map((item, index) => /*#__PURE__*/React.createElement(Transition, {
      key: index,
      onRemoved: () => {
        if (index === 0) reAddChildren();
      },
      removeOnExited: true
    }, status => (/*#__PURE__*/React.cloneElement(item, {
      className: classNames([classes.item, status]),
      elevation: item.props.elevation !== undefined ? item.props.elevation : false,
      version: item.props.version !== undefined ? item.props.version : 'filled',
      color: item.props.color !== undefined ? item.props.color : color,
      tonal: item.props.tonal !== undefined ? item.props.tonal : tonal,
      style: _objectSpread(_objectSpread({}, item.props.style), status.includes('enter') && {
        transitionDelay: `${index * 70}ms`
      })
    }))));
  };
  const makeMain = values => {
    return React.Children.toArray(values).map((item, index) => /*#__PURE__*/React.createElement(Transition, {
      key: index,
      onRemoved: () => {
        if (index === 0) reAddMain();
      },
      removeOnExited: true
    }, status => (/*#__PURE__*/React.cloneElement(item, {
      className: classNames([classes.mainItem, status]),
      color: item.props.color !== undefined ? item.props.color : color,
      tonal: item.props.tonal !== undefined ? item.props.tonal : tonal && ['onesy-Fab'].includes(item.type?.displayName) ? 'secondary' : tonal
    }))));
  };
  const [init, setInit] = React.useState(false);
  const [children, setChildren] = React.useState(() => makeChildren(children_));
  const [main, setMain] = React.useState(() => makeMain(main_));
  const [inProp, setInProp] = React.useState(true);
  const refs = {
    preChildren: React.useRef(undefined),
    preMain: React.useRef(undefined)
  };
  React.useEffect(() => {
    setInit(true);
  }, []);
  const reAddChildren = () => {
    setChildren(makeChildren(refs.preChildren.current));
    setInProp(true);
    refs.preChildren.current = undefined;
  };
  const reAddMain = () => {
    setMain(makeMain(refs.preMain.current));
    setInProp(true);
    refs.preMain.current = undefined;
  };
  React.useEffect(() => {
    if (init) {
      if (!noTransition) {
        refs.preChildren.current = children_;
        setInProp(false);
      } else setChildren(makeChildren(children_));
    }
  }, [React.Children.toArray(children_).map(item => item.key).join('')]);
  React.useEffect(() => {
    if (init) {
      if (!noTransition) {
        refs.preMain.current = main_;
        setInProp(false);
      } else setMain(makeMain(main_));
    }
  }, [React.Children.toArray(main_).map(item => item.key).join('')]);
  return /*#__PURE__*/React.createElement(Surface, _extends({
    ref: ref,
    color: color,
    tonal: tonal,
    gap: 4,
    direction: "row",
    align: "center",
    justify: "space-between",
    Component: Line,
    className: classNames([staticClassName('BottomAppBar', theme) && ['onesy-BottomAppBar-root', `onesy-BottomAppBar-size-${size}`], className, classes.root, classes[`size_${size}`], fixed && classes.fixed])
  }, other), !!children.length && /*#__PURE__*/React.createElement(Line, {
    direction: "row",
    align: "center",
    justify: "flex-start",
    gap: 0
  }, children.map(item => (/*#__PURE__*/React.cloneElement(item, {
    in: inProp
  })))), !!main.length && /*#__PURE__*/React.createElement(Line, {
    direction: "row",
    align: "center",
    justify: "flex-end"
  }, main.map(item => (/*#__PURE__*/React.cloneElement(item, {
    in: inProp
  })))));
});
BottomAppBar.displayName = 'onesy-BottomAppBar';
export default BottomAppBar;

==> ui-react-1.1.440.tgz: package/esm/BottomAppBar/BottomAppBar.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["tonal", "color", "size", "main", "fixed", "noTransition", "className", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import LineElement from '../Line';
import SurfaceElement from '../Surface';
import TransitionElement from '../Transition';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {
    zIndex: theme.z_index.app_bar,
    width: '100%',
    height: '80px',
    paddingBlock: theme.methods.space.value(1.5, 'px'),
    paddingInline: `${theme.methods.space.value(0.5, 'px')} ${theme.methods.space.value(2, 'px')}`
  },
  size_small: {
    height: '72px'
  },
  size_regular: {
    height: '80px'
  },
  size_large: {
    height: '88px'
  },
  fixed: {
    position: 'fixed',
    insetInline: '0px',
    bottom: '0px'
  },
  item: {
    opacity: '0',
    transform: 'translateY(100%)',
    transition: theme?.methods.transitions.make(['opacity', 'transform'], {
      duration: 'rg',
      timing_function: 'standard'
    }),
    '&.enter': {
      opacity: '0',
      transform: 'translateY(100%)'
    },
    '&.entering': {
      opacity: '1',
      transform: 'translateY(0%)'
    },
    '&.entered': {
      opacity: '1',
      transform: 'translateY(0%)'
    },
    '&.exit': {
      opacity: '1',
      transform: 'translateY(0%)'
    },
    '&.exiting': {
      opacity: '0',
      transform: 'translateY(0%)'
    },
    '&.exited': {
      opacity: '0',
      transform: 'translateY(0%)'
    }
  },
  mainItem: {
    opacity: '0',
    transform: 'scale(0.75)',
    transition: theme?.methods.transitions.make(['opacity', 'transform'], {
      duration: 'rg',
      timing_function: 'standard'
    }),
    '&.enter': {
      opacity: '0',
      transform: 'scale(0.75)'
    },
    '&.entering': {
      opacity: '1',
      transform: 'scale(1)'
    },
    '&.entered': {
      opacity: '1',
      transform: 'scale(1)'
    },
    '&.exit': {
      opacity: '1',
      transform: 'scale(1)'
    },
    '&.exiting': {
      opacity: '0',
      transform: 'scale(1)'
    },
    '&.exited': {
      opacity: '0',
      transform: 'scale(1)'
    }
  }
}), {
  name: 'amaui-BottomAppBar'
});
const BottomAppBar = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiBottomAppBar?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Surface = React.useMemo(() => theme?.elements?.Surface || SurfaceElement, [theme]);
  const Transition = React.useMemo(() => theme?.elements?.Transition || TransitionElement, [theme]);
  const {
      tonal = true,
      color = 'primary',
      size = 'regular',
      main: main_,
      fixed,
      noTransition,
      className,
      children: children_
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const makeChildren = values => {
    return React.Children.toArray(values).map((item, index) => /*#__PURE__*/React.createElement(Transition, {
      key: index,
      onRemoved: () => {
        if (index === 0) reAddChildren();
      },
      removeOnExited: true
    }, status => /*#__PURE__*/React.cloneElement(item, {
      className: classNames([classes.item, status]),
      elevation: item.props.elevation !== undefined ? item.props.elevation : false,
      version: item.props.version !== undefined ? item.props.version : 'filled',
      color: item.props.color !== undefined ? item.props.color : color,
      tonal: item.props.tonal !== undefined ? item.props.tonal : tonal,
      style: _objectSpread(_objectSpread({}, item.props.style), status.includes('enter') && {
        transitionDelay: `${index * 70}ms`
      })
    })));
  };
  const makeMain = values => {
    return React.Children.toArray(values).map((item, index) => /*#__PURE__*/React.createElement(Transition, {
      key: index,
      onRemoved: () => {
        if (index === 0) reAddMain();
      },
      removeOnExited: true
    }, status => /*#__PURE__*/React.cloneElement(item, {
      className: classNames([classes.mainItem, status]),
      color: item.props.color !== undefined ? item.props.color : color,
      tonal: item.props.tonal !== undefined ? item.props.tonal : tonal && ['amaui-Fab'].includes(item.type?.displayName) ? 'secondary' : tonal
    })));
  };
  const [init, setInit] = React.useState(false);
  const [children, setChildren] = React.useState(() => makeChildren(children_));
  const [main, setMain] = React.useState(() => makeMain(main_));
  const [inProp, setInProp] = React.useState(true);
  const refs = {
    preChildren: React.useRef(),
    preMain: React.useRef()
  };
  React.useEffect(() => {
    setInit(true);
  }, []);
  const reAddChildren = () => {
    setChildren(makeChildren(refs.preChildren.current));
    setInProp(true);
    refs.preChildren.current = undefined;
  };
  const reAddMain = () => {
    setMain(makeMain(refs.preMain.current));
    setInProp(true);
    refs.preMain.current = undefined;
  };
  React.useEffect(() => {
    if (init) {
      if (!noTransition) {
        refs.preChildren.current = children_;
        setInProp(false);
      } else setChildren(makeChildren(children_));
    }
  }, [React.Children.toArray(children_).map(item => item.key).join('')]);
  React.useEffect(() => {
    if (init) {
      if (!noTransition) {
        refs.preMain.current = main_;
        setInProp(false);
      } else setMain(makeMain(main_));
    }
  }, [React.Children.toArray(main_).map(item => item.key).join('')]);
  return /*#__PURE__*/React.createElement(Surface, _extends({
    ref: ref,
    color: color,
    tonal: tonal,
    gap: 4,
    direction: "row",
    align: "center",
    justify: "space-between",
    Component: Line,
    className: classNames([staticClassName('BottomAppBar', theme) && ['amaui-BottomAppBar-root'], className, classes.root, classes[`size_${size}`], fixed && classes.fixed])
  }, other), !!children.length && /*#__PURE__*/React.createElement(Line, {
    direction: "row",
    align: "center",
    justify: "flex-start",
    gap: 0
  }, children.map(item => /*#__PURE__*/React.cloneElement(item, {
    in: inProp
  }))), !!main.length && /*#__PURE__*/React.createElement(Line, {
    direction: "row",
    align: "center",
    justify: "flex-end"
  }, main.map(item => /*#__PURE__*/React.cloneElement(item, {
    in: inProp
  }))));
});
BottomAppBar.displayName = 'amaui-BottomAppBar';
export default BottomAppBar;
